==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkCaptionRepresentation.java <==
// java wrapper for vtkCaptionRepresentation object
//

package vtk;
import vtk.*;

public class vtkCaptionRepresentation extends vtkBorderRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAnchorPosition_2(double id0[]);
  public void SetAnchorPosition(double id0[])
    { SetAnchorPosition_2(id0); }

  private native void GetAnchorPosition_3(double id0[]);
  public void GetAnchorPosition(double id0[])
    { GetAnchorPosition_3(id0); }

  private native void SetCaptionActor2D_4(vtkCaptionActor2D id0);
  public void SetCaptionActor2D(vtkCaptionActor2D id0)
    { SetCaptionActor2D_4(id0); }

  private native long GetCaptionActor2D_5();
  public vtkCaptionActor2D GetCaptionActor2D() {
    long temp = GetCaptionActor2D_5();

    if (temp == 0) return null;
    return (vtkCaptionActor2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetAnchorRepresentation_6(vtkPointHandleRepresentation3D id0);
  public void SetAnchorRepresentation(vtkPointHandleRepresentation3D id0)
    { SetAnchorRepresentation_6(id0); }

  private native long GetAnchorRepresentation_7();
  public vtkPointHandleRepresentation3D GetAnchorRepresentation() {
    long temp = GetAnchorRepresentation_7();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void BuildRepresentation_8();
  public void BuildRepresentation()
    { BuildRepresentation_8(); }

  private native void GetSize_9(double id0[]);
  public void GetSize(double id0[])
    { GetSize_9(id0); }

  private native void GetActors2D_10(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_10(id0); }

  private native void ReleaseGraphicsResources_11(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_11(id0); }

  private native int RenderOverlay_12(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_12(id0); }

  private native int RenderOpaqueGeometry_13(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_13(id0); }

  private native int RenderTranslucentPolygonalGeometry_14(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_14(id0); }

  private native int HasTranslucentPolygonalGeometry_15();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_15(); }

  private native void SetFontFactor_16(double id0);
  public void SetFontFactor(double id0)
    { SetFontFactor_16(id0); }

  private native double GetFontFactorMinValue_17();
  public double GetFontFactorMinValue()
    { return GetFontFactorMinValue_17(); }

  private native double GetFontFactorMaxValue_18();
  public double GetFontFactorMaxValue()
    { return GetFontFactorMaxValue_18(); }

  private native double GetFontFactor_19();
  public double GetFontFactor()
    { return GetFontFactor_19(); }

  public vtkCaptionRepresentation() { super(); }

  public vtkCaptionRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv6h.pkg.tar.xz: vtk/vtkCaptionRepresentation.java <==
// java wrapper for vtkCaptionRepresentation object
//

package vtk;
import vtk.*;

public class vtkCaptionRepresentation extends vtkBorderRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAnchorPosition_2(double id0[]);
  public void SetAnchorPosition(double id0[])
    { SetAnchorPosition_2(id0); }

  private native void GetAnchorPosition_3(double id0[]);
  public void GetAnchorPosition(double id0[])
    { GetAnchorPosition_3(id0); }

  private native void SetCaptionActor2D_4(vtkCaptionActor2D id0);
  public void SetCaptionActor2D(vtkCaptionActor2D id0)
    { SetCaptionActor2D_4(id0); }

  private native long GetCaptionActor2D_5();
  public vtkCaptionActor2D GetCaptionActor2D() {
    long temp = GetCaptionActor2D_5();

    if (temp == 0) return null;
    return (vtkCaptionActor2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAnchorRepresentation_6(vtkPointHandleRepresentation3D id0);
  public void SetAnchorRepresentation(vtkPointHandleRepresentation3D id0)
    { SetAnchorRepresentation_6(id0); }

  private native long GetAnchorRepresentation_7();
  public vtkPointHandleRepresentation3D GetAnchorRepresentation() {
    long temp = GetAnchorRepresentation_7();

    if (temp == 0) return null;
    return (vtkPointHandleRepresentation3D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void BuildRepresentation_8();
  public void BuildRepresentation()
    { BuildRepresentation_8(); }

  private native void GetSize_9(double id0[]);
  public void GetSize(double id0[])
    { GetSize_9(id0); }

  private native void GetActors2D_10(vtkPropCollection id0);
  public void GetActors2D(vtkPropCollection id0)
    { GetActors2D_10(id0); }

  private native void ReleaseGraphicsResources_11(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_11(id0); }

  private native int RenderOverlay_12(vtkViewport id0);
  public int RenderOverlay(vtkViewport id0)
    { return RenderOverlay_12(id0); }

  private native int RenderOpaqueGeometry_13(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_13(id0); }

  private native int RenderTranslucentPolygonalGeometry_14(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_14(id0); }

  private native int HasTranslucentPolygonalGeometry_15();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_15(); }

  private native void SetFontFactor_16(double id0);
  public void SetFontFactor(double id0)
    { SetFontFactor_16(id0); }

  private native double GetFontFactorMinValue_17();
  public double GetFontFactorMinValue()
    { return GetFontFactorMinValue_17(); }

  private native double GetFontFactorMaxValue_18();
  public double GetFontFactorMaxValue()
    { return GetFontFactorMaxValue_18(); }

  private native double GetFontFactor_19();
  public double GetFontFactor()
    { return GetFontFactor_19(); }

  public vtkCaptionRepresentation() { super(); }

  public vtkCaptionRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
